#include <iostream>
#include <vector>
#include <queue>
#include <stack>
#include <algorithm>
#include <sstream>
#include <math.h>
#include <cmath>
#include <set>
#include <deque>
#include <climits>


using namespace std;

struct Part {
    int size;
    vector<int> points;

    int front() {
        return points[0];
    }

    int back() {
        return size - points.back();
    }

    int frontConnection(Part before) {
        return before.back() + front();
    }

    int backConnection(Part after) {
        return after.front() + back();
    }

    set<int> getHardDistances() {
        set<int> res;
        for (int i = 0; i < points.size() - 1; i++)
        {
            res.insert(points[i + 1] - points[i]);
        }
        return res;
    }
};

deque<int> canGen(vector<Part> allParts, deque<int> sequence, set<int> used, int length) {
    if (sequence.size() == allParts.size()) {
        return sequence;
    }
    for (int i = 0; i < allParts.size(); i++)
    {
        if (used.find(i) != used.end()) {
            continue;
        }

        if (allParts[i].frontConnection(allParts[sequence.back()]) == length) {
            deque<int> tmpsequence = sequence;
            tmpsequence.push_back(i);
            set<int> tmpused = used;
            tmpused.insert(i);
            deque<int> result = canGen(allParts, tmpsequence, tmpused, length);
            if (result.size() != 0) {
                return result;
            }
        }

        if (allParts[i].backConnection(allParts[sequence.front()]) == length) {
            deque<int> tmpsequence = sequence;
            tmpsequence.push_front(i);
            set<int> tmpused = used;
            tmpused.insert(i);
            deque<int> result = canGen(allParts, tmpsequence, tmpused, length);
            if (result.size() != 0) {
                return result;
            }
        }
    }

    return deque<int>();
}


int main()
{

    vector<Part> parts;
    int n;
    cin >> n;
    parts.resize(n);

    int maxIndex = -1;
    int maxCount = 0;

    int maxBack = 0;
    int maxFront = 0;

    int minBack = INT_MAX;
    int minFront = INT_MAX;

    set<int> hardDistances;

    for (int i = 0; i < n; i++)
    {
        int m;
        cin >> m;

        if (m > maxCount) {
            maxIndex = i;
            maxCount = m;
        }

        parts[i].points.resize(m);
        cin >> parts[i].size;

        for (int j = 0; j < m; j++)
        {
            cin >> parts[i].points[j];
        }

        sort(parts[i].points.begin(), parts[i].points.end());

        maxBack = max(maxBack, parts[i].back());
        maxFront = max(maxFront, parts[i].front());

        minFront = min(minFront, parts[i].front());
        minBack = min(minBack, parts[i].back());

        for (int dist : parts[i].getHardDistances())
        {
            hardDistances.insert(dist);
        }
    }

    if (hardDistances.size() > 1) {
        cout << "No\n";
        return 0;
    }

    set<int> distsToCheck;
    for (int d : hardDistances)
    {
        distsToCheck.insert(d);
    }

    if (hardDistances.size() == 0) {
        for (int i = minFront + minBack; i <= maxFront + maxBack; i++)
        {
            distsToCheck.insert(i);
        }
    }

    for (auto dist : distsToCheck)
    {
        deque<int> startSequence;
        startSequence.push_back(maxIndex);
        set<int> used;
        used.insert(maxIndex);
        deque<int> genSequence = canGen(parts, startSequence, used, dist);
        if (genSequence.size() != 0) {
            cout << "Yes\n";
            for (auto ind : genSequence)
            {
                cout << ind + 1 << " ";
            }
            return 0;
        }
    }

    cout << "No\n";
}

