#include <iostream>
#include <vector>
#include <random>
#include <algorithm>

using namespace std;

const int MAX_N = 1e5;

vector<int> leftMatch(MAX_N, -1);
vector<int> rightMatch(MAX_N, -1);
vector<int> graph[MAX_N];
vector<bool> used(MAX_N);

bool dfs(int v) {
    for (int u : graph[v]) {
        if (!used[u] && (rightMatch[u] == -1 || dfs(rightMatch[u]))) {
            leftMatch[v] = u;
            return true;
        }
        used[u] = true;
    }
    return false;
}

int maxPairMatch(int n) {
    for (int i = 0; i < n; i++) {
        if (leftMatch[i] == -1) {
            used.assign(n, false);
            dfs(i);
        }
    }
    int cnt = 0;
    for (int i = 0; i < n; i++) {
        if (leftMatch[i] != -1) cnt++;
    }
    return cnt;
}

struct Stick {
    int length;
    vector<int> seps;
    explicit Stick() {
        length = 0;
    }
    Stick(int length, vector<int> &seps) {
        this->length = length;
        this->seps = seps;
    }
};

int checkStick(const Stick &stick) {
    int dist = stick.seps[1] - stick.seps[0];
    for (int i = 2; i < (int) stick.seps.size(); i++) {
        if (stick.seps[i + 1] - stick.seps[i] != dist) return -1;
    }
    return dist;
}

void coutNo() {
    cout << "No" << std::endl;
    exit(0);
}

struct SuperStick {
    int length, first, last;
    SuperStick(const Stick &stick) {
        this->length = stick.length;
        this->first = *stick.seps.begin();
        this->last = stick.seps.back();
    }
};

vector<int> path;
void gaySearch(int vertex, int cnt, int n) {
    if (cnt == n) {
        cout << "Yes" << endl;
        for (int v : path) {
            cout << v + 1 << ' ';
        }
        cout << endl;
        exit(0);
    }
    for (int u : graph[vertex]) {
        if (!used[u]) {
            used[u] = true;
            path.push_back(u);
            gaySearch(u, cnt + 1, n);
            path.pop_back();
            used[u] = false;
        }
    }
}

int main() {
    int n; cin >> n;
    vector<pair<Stick, int>> orderedSticks;
    for (int i = 0; i < n; i++) {
        int len, sz; cin >> sz >> len;
        vector<int> coords(sz);
        for (int &j : coords) cin >> j;
        orderedSticks.push_back({Stick(len, coords), i});
    }
    int dist = -1;
    for (int i = 0; i < n; i++) {
        if (orderedSticks[i].first.seps.size() > 1) {
            int d = checkStick(orderedSticks[i].first);
            if (d == -1) {
                coutNo();
            }
            if (dist != -1) {
                if (d != dist) {
                    coutNo();
                }
            }
            dist = d;
        }
    }
    vector<SuperStick> sticks;
    for (int i = 0; i < n; i++) {
        sticks.push_back(SuperStick(orderedSticks[i].first));
    }
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < n; j++) {
            if (i == j) continue;
            if (sticks[i].length - sticks[i].last + sticks[j].first == dist) {
                graph[i].push_back(j);
            }
        }
    }
    vector<int> vtx;
    for (int i = 0; i < n; i++) vtx.push_back(i);
    random_shuffle(vtx.begin(), vtx.end());
    for (int i = 0; i < min(100, n); i++) {
        used[i] = true;
        path.push_back(i);
        gaySearch(i, 1, n);
        used[i] = false;
        path.pop_back();
    }
    coutNo();

}