#include <bits/stdc++.h>

using namespace std;
using ll = long long;

#define len(a) int((a).size())
#define all(a) (a).begin(), (a).end()
#define forn(i, l, r) for (int i = (l); i < (r); i++)

#ifdef LOCAL
#include "/home/olymp/codes/debug.h"
#else
#define dbg(...)
#endif

mt19937 rng(chrono::steady_clock::now().time_since_epoch().count());

struct Dinic {
	struct Edge {
		int to;
		int w;
		int index;

		Edge() {}
		Edge(int to, int w, int index) : to(to), w(w), index(index) {}
	};

	int n;
	int s, t;
	vector<vector<Edge>> g;

	int curIndex;
	vector<int> flow;

	Dinic() {}
	Dinic(int n, int s, int t) : n(n), s(s), t(t), g(n), curIndex(0) {}

	inline void addEdge(int v, int u, int w) {
		dbg(v, u, w);
		g[v].push_back(Edge(u, w, curIndex++));
		g[u].push_back(Edge(v, 0, curIndex++));
		flow.push_back(0);
		flow.push_back(0);
	}

	vector<int> dist;

	inline bool bfs() {
		dist = vector<int>(n, n);
		dist[s] = 0;
		queue<int> q;
		q.push(s);

		while (len(q)) {
			int v = q.front();
			q.pop();
			for (auto [to, w, index] : g[v]) {
				if (flow[index] == w) continue;
				if (dist[to] <= dist[v] + 1) continue;
				dist[to] = dist[v] + 1;
				q.push(to);
			}
		}
		return dist[t] != n;
	}

	vector<int> head;

	inline int dfs(int v, int mnEdge) {
		if (v == t) return mnEdge;
		for (; head[v] < len(g[v]); head[v]++) {
			auto [to, w, index] = g[v][head[v]];
			if (dist[to] != dist[v] + 1) continue;
			if (flow[index] == w) continue;
			if (int cur = dfs(to, min(mnEdge, w - flow[index]))) {
				flow[index] += cur;
				flow[index ^ 1] -= cur;
				return cur;
			}
		}
		return 0;
	}

	inline pair<vector<vector<int>>, int> solve() {
		int curFlow = 0;
		while (bfs()) {
			head = vector<int>(n, 0);
			while (int cur = dfs(s, INT_MAX)) curFlow += cur;
		}

		assert(n % 2 == 0);
		vector<vector<int>> nxt(n / 2 - 1);
		forn (i, 0, n / 2 - 1) {
			for (auto [j, w, index] : g[i]) {
				if (j != s && j != t && j >= n / 2 - 1 && flow[index] && index % 2 == 0) {
					nxt[i].push_back(j - (n / 2 - 1));
				}
			}
		}
		return {nxt, curFlow};
	}
};

void dfsTopsort(int v, vector<vector<int>> &g, vector<int> &topsort, vector<char> &used) {
	used[v] = 1;
	for (auto u : g[v]) {
		if (!used[u]) dfsTopsort(u, g, topsort, used);
	}
	topsort.push_back(v);
}

inline void gg() {
	cout << "No\n";
	exit(0);
}

signed main() {
	ios::sync_with_stdio(false);
	cin.tie(nullptr);

	int n;
	cin >> n;
	vector<pair<int, int>> a;
	int del = -1;
	forn (i, 0, n) {
		int m, s;
		cin >> m >> s;
		vector<int> positions(m);
		forn (j, 0, m) cin >> positions[j];
		a.emplace_back(positions[0], s - positions.back());
		if (m == 1) continue;

		forn (j, 1, m) {
			int cur = positions[j] - positions[j - 1];
			if (del == -1) del = cur;
			else if (del != cur) gg();
		}
	}

	if (n == 1) {
		cout << "Yes\n1\n";
		exit(0);
	}

#ifndef LOCAL
	auto brute = [&]() {
		vector<int> perm(n);
		iota(all(perm), 0);
		do {
			bool ok = true;
			int curVal = -1;
			forn (i, 1, n) {
				int cur = perm[i];
				int prev = perm[i - 1];
				int x = a[cur].first + a[prev].second;
				if (del != -1) ok &= (x == del);
				else if (curVal == -1) curVal = x;
				else ok &= (curVal == x);
			}
			if (ok) {
				cout << "Yes\n";
				forn (i, 0, n) cout << perm[i] + 1 << " \n"[i == n - 1];
				exit(0);
			}
		} while (next_permutation(all(perm)));
		gg();
	};
	if (n <= 8) brute();
#endif

	auto check = [&](vector<int> &perm, int del) {
		if (len(perm) != n) return;

		bool correct = true;
		forn (i, 1, n) {
			int cur = perm[i];
			int prev = perm[i - 1];
			int x = a[prev].second + a[cur].first;
			correct &= (x == del);
			if (!correct) break;
		}

		if (correct) {
			cout << "Yes\n";
			forn (i, 0, n) cout << perm[i] + 1 << " \n"[i == n - 1];
			exit(0);
		}
	};

	auto solveFixed = [&](int del) {
		dbg("start checking", del);

		map<int, vector<int>> classes;
		forn (i, 0, n) classes[a[i].first].push_back(i);
		int nClasses = len(classes);

		map<int, int> index;
		int curIndex = n;
		for (auto [cl, vec] : classes) {
			index[cl] = curIndex;
			curIndex++;
		}

		vector<pair<int, int>> edges;
		auto addEdge = [&](int v, int u) {
			edges.emplace_back(v, u);
		};

		forn (i, 0, n) {
			int sec = a[i].second;
			if (sec > del) continue;
			if (classes.find(del - sec) == classes.end()) continue;
			addEdge(i, index[del - sec]);
		}

		forn (i, 0, n) {
			int fir = a[i].first;
			if (fir > del) continue;
			addEdge(index[fir], i);
		}
		dbg(edges);

		int s = 2 * (n + nClasses);
		int t = s + 1;
		dbg(s, t, n + nClasses);
		Dinic g(t + 1, s, t);
		for (auto [v, u] : edges) {
			g.addEdge(v, u + n + nClasses, 1);
		}
		forn (i, 0, n + nClasses) {
			g.addEdge(s, i, int(1));
			g.addEdge(i + n + nClasses, t, int(1e9));
		}

		auto [nxt, flow] = g.solve();
		dbg(flow);
		if (flow != len(edges)) return;

		vector<int> rngOrd(n + nClasses);
		iota(all(rngOrd), 0);
		while (double(clock()) / CLOCKS_PER_SEC < 1.6) {
			vector<char> used(n + nClasses);
			vector<int> topsort;

			shuffle(all(rngOrd), rng);
			// forn (i, 0, n + nClasses) shuffle(all(nxt[i]), rng);
			for (auto i : rngOrd) {
				if (!used[i]) dfsTopsort(i, nxt, topsort, used);
			}

			reverse(all(topsort));
			vector<int> ord;
			forn (i, 0, len(topsort)) {
				if (topsort[i] < n) ord.push_back(topsort[i]);
			}

			check(ord, del);
			reverse(all(ord));
			check(ord, del);
		}
	};

	if (del != -1) solveFixed(del);
	else {
		map<int, int> cnt;
		forn (i, 0, n) {
			forn (j, 0, n) {
				if (i != j) cnt[a[i].first + a[j].second]++;
			}
		}
		for (auto [x, num] : cnt) {
			if (num >= n - 1) solveFixed(x);
			// solveFixed(x);
		}
	}
	gg();
}
